What's new in the latest versions
=================================

The new version of OMEGAlpes v0.4.3 is available!
The release is from 29th of April 2022.

.. toctree::
   :maxdepth: 2

   new_functionalities/v0.4.3


Information about the latest versions
-------------------------------------

.. toctree::
   :maxdepth: 1

   new_functionalities/v0.4.2

.. toctree::
   :maxdepth: 1

   new_functionalities/v0.4.1

.. toctree::
   :maxdepth: 1

   new_functionalities/v0.4.0

.. toctree::
   :maxdepth: 1

   new_functionalities/v0.3.1

.. toctree::
   :maxdepth: 1

   new_functionalities/v0.3.0
